# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Accesses the google.cloud.talent.v4beta1 JobService API."""

import functools
import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.client_options
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.gapic_v1.routing_header
import google.api_core.grpc_helpers
import google.api_core.operation
import google.api_core.operations_v1
import google.api_core.page_iterator
import google.api_core.path_template
import grpc

from google.cloud.talent_v4beta1.gapic import enums
from google.cloud.talent_v4beta1.gapic import job_service_client_config
from google.cloud.talent_v4beta1.gapic.transports import job_service_grpc_transport
from google.cloud.talent_v4beta1.proto import application_pb2
from google.cloud.talent_v4beta1.proto import application_service_pb2
from google.cloud.talent_v4beta1.proto import application_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import common_pb2
from google.cloud.talent_v4beta1.proto import company_pb2
from google.cloud.talent_v4beta1.proto import company_service_pb2
from google.cloud.talent_v4beta1.proto import company_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import completion_service_pb2
from google.cloud.talent_v4beta1.proto import completion_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import event_pb2
from google.cloud.talent_v4beta1.proto import event_service_pb2
from google.cloud.talent_v4beta1.proto import event_service_pb2_grpc
from google.cloud.talent_v4beta1.proto import filters_pb2
from google.cloud.talent_v4beta1.proto import histogram_pb2
from google.cloud.talent_v4beta1.proto import job_pb2
from google.cloud.talent_v4beta1.proto import job_service_pb2
from google.cloud.talent_v4beta1.proto import job_service_pb2_grpc
from google.longrunning import operations_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2


_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("google-cloud-talent").version


class JobServiceClient(object):
    """A service handles job management, including job CRUD, enumeration and search."""

    SERVICE_ADDRESS = "jobs.googleapis.com:443"
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = "google.cloud.talent.v4beta1.JobService"

    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            JobServiceClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(filename)
        kwargs["credentials"] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    @classmethod
    def company_path(cls, project, tenant, company):
        """Return a fully-qualified company string."""
        return google.api_core.path_template.expand(
            "projects/{project}/tenants/{tenant}/companies/{company}",
            project=project,
            tenant=tenant,
            company=company,
        )

    @classmethod
    def company_without_tenant_path(cls, project, company):
        """Return a fully-qualified company_without_tenant string."""
        return google.api_core.path_template.expand(
            "projects/{project}/companies/{company}", project=project, company=company
        )

    @classmethod
    def job_path(cls, project, tenant, jobs):
        """Return a fully-qualified job string."""
        return google.api_core.path_template.expand(
            "projects/{project}/tenants/{tenant}/jobs/{jobs}",
            project=project,
            tenant=tenant,
            jobs=jobs,
        )

    @classmethod
    def job_without_tenant_path(cls, project, jobs):
        """Return a fully-qualified job_without_tenant string."""
        return google.api_core.path_template.expand(
            "projects/{project}/jobs/{jobs}", project=project, jobs=jobs
        )

    @classmethod
    def project_path(cls, project):
        """Return a fully-qualified project string."""
        return google.api_core.path_template.expand(
            "projects/{project}", project=project
        )

    @classmethod
    def tenant_path(cls, project, tenant):
        """Return a fully-qualified tenant string."""
        return google.api_core.path_template.expand(
            "projects/{project}/tenants/{tenant}", project=project, tenant=tenant
        )

    def __init__(
        self,
        transport=None,
        channel=None,
        credentials=None,
        client_config=None,
        client_info=None,
        client_options=None,
    ):
        """Constructor.

        Args:
            transport (Union[~.JobServiceGrpcTransport,
                    Callable[[~.Credentials, type], ~.JobServiceGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            client_options (Union[dict, google.api_core.client_options.ClientOptions]):
                Client options used to set user options on the client. API Endpoint
                should be set through client_options.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config is not None:
            warnings.warn(
                "The `client_config` argument is deprecated.",
                PendingDeprecationWarning,
                stacklevel=2,
            )
        else:
            client_config = job_service_client_config.config

        if channel:
            warnings.warn(
                "The `channel` argument is deprecated; use " "`transport` instead.",
                PendingDeprecationWarning,
                stacklevel=2,
            )

        api_endpoint = self.SERVICE_ADDRESS
        if client_options:
            if type(client_options) == dict:
                client_options = google.api_core.client_options.from_dict(
                    client_options
                )
            if client_options.api_endpoint:
                api_endpoint = client_options.api_endpoint

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=job_service_grpc_transport.JobServiceGrpcTransport,
                    address=api_endpoint,
                )
            else:
                if credentials:
                    raise ValueError(
                        "Received both a transport instance and "
                        "credentials; these are mutually exclusive."
                    )
                self.transport = transport
        else:
            self.transport = job_service_grpc_transport.JobServiceGrpcTransport(
                address=api_endpoint, channel=channel, credentials=credentials
            )

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION
            )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config["interfaces"][self._INTERFACE_NAME]
        )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def create_job(
        self,
        parent,
        job,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Creates a new job.

        Typically, the job becomes searchable within 10 seconds, but it may take
        up to 5 minutes.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `job`:
            >>> job = {}
            >>>
            >>> response = client.create_job(parent, job)

        Args:
            parent (str): Required. The resource name of the tenant under which the job is
                created.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenant/bar". If tenant id is unspecified a
                default tenant is created. For example, "projects/foo".
            job (Union[dict, ~google.cloud.talent_v4beta1.types.Job]): Required. The Job to be created.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.Job`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.talent_v4beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "create_job" not in self._inner_api_calls:
            self._inner_api_calls[
                "create_job"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.create_job,
                default_retry=self._method_configs["CreateJob"].retry,
                default_timeout=self._method_configs["CreateJob"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.CreateJobRequest(parent=parent, job=job)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["create_job"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def get_job(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Retrieves the specified job, whose status is OPEN or recently EXPIRED
        within the last 90 days.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> name = client.job_path('[PROJECT]', '[TENANT]', '[JOBS]')
            >>>
            >>> response = client.get_job(name)

        Args:
            name (str): Required. The resource name of the job to retrieve.

                The format is
                "projects/{project\_id}/tenants/{tenant\_id}/jobs/{job\_id}". For
                example, "projects/foo/tenants/bar/jobs/baz".

                If tenant id is unspecified, the default tenant is used. For example,
                "projects/foo/jobs/bar".
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.talent_v4beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "get_job" not in self._inner_api_calls:
            self._inner_api_calls[
                "get_job"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_job,
                default_retry=self._method_configs["GetJob"].retry,
                default_timeout=self._method_configs["GetJob"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.GetJobRequest(name=name)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["get_job"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def update_job(
        self,
        job,
        update_mask=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Updates specified job.

        Typically, updated contents become visible in search results within 10
        seconds, but it may take up to 5 minutes.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> # TODO: Initialize `job`:
            >>> job = {}
            >>>
            >>> response = client.update_job(job)

        Args:
            job (Union[dict, ~google.cloud.talent_v4beta1.types.Job]): Required. The Job to be updated.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.Job`
            update_mask (Union[dict, ~google.cloud.talent_v4beta1.types.FieldMask]): Strongly recommended for the best service experience.

                If ``update_mask`` is provided, only the specified fields in ``job`` are
                updated. Otherwise all the fields are updated.

                A field mask to restrict the fields that are updated. Only top level
                fields of ``Job`` are supported.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.talent_v4beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "update_job" not in self._inner_api_calls:
            self._inner_api_calls[
                "update_job"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.update_job,
                default_retry=self._method_configs["UpdateJob"].retry,
                default_timeout=self._method_configs["UpdateJob"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.UpdateJobRequest(job=job, update_mask=update_mask)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("job.name", job.name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["update_job"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def delete_job(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Deletes the specified job.

        Typically, the job becomes unsearchable within 10 seconds, but it may take
        up to 5 minutes.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> name = client.job_path('[PROJECT]', '[TENANT]', '[JOBS]')
            >>>
            >>> client.delete_job(name)

        Args:
            name (str): Required. The resource name of the job to be deleted.

                The format is
                "projects/{project\_id}/tenants/{tenant\_id}/jobs/{job\_id}". For
                example, "projects/foo/tenants/bar/jobs/baz".

                If tenant id is unspecified, the default tenant is used. For example,
                "projects/foo/jobs/bar".
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "delete_job" not in self._inner_api_calls:
            self._inner_api_calls[
                "delete_job"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.delete_job,
                default_retry=self._method_configs["DeleteJob"].retry,
                default_timeout=self._method_configs["DeleteJob"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.DeleteJobRequest(name=name)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        self._inner_api_calls["delete_job"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def list_jobs(
        self,
        parent,
        filter_,
        page_size=None,
        job_view=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Lists jobs by filter.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `filter_`:
            >>> filter_ = ''
            >>>
            >>> # Iterate over all results
            >>> for element in client.list_jobs(parent, filter_):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.list_jobs(parent, filter_).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): Required. The resource name of the tenant under which the job is
                created.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenant/bar". If tenant id is unspecified, a
                default tenant is created. For example, "projects/foo".
            filter_ (str): Required. The filter string specifies the jobs to be enumerated.

                Supported operator: =, AND

                The fields eligible for filtering are:

                -  ``companyName`` (Required)
                -  ``requisitionId``
                -  ``status`` Available values: OPEN, EXPIRED, ALL. Defaults to OPEN if
                   no value is specified.

                Sample Query:

                -  companyName = "projects/foo/tenants/bar/companies/baz"
                -  companyName = "projects/foo/tenants/bar/companies/baz" AND
                   requisitionId = "req-1"
                -  companyName = "projects/foo/tenants/bar/companies/baz" AND status =
                   "EXPIRED"
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            job_view (~google.cloud.talent_v4beta1.types.JobView): The desired job attributes returned for jobs in the search response.
                Defaults to ``JobView.JOB_VIEW_FULL`` if no value is specified.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~google.cloud.talent_v4beta1.types.Job` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "list_jobs" not in self._inner_api_calls:
            self._inner_api_calls[
                "list_jobs"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.list_jobs,
                default_retry=self._method_configs["ListJobs"].retry,
                default_timeout=self._method_configs["ListJobs"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.ListJobsRequest(
            parent=parent, filter=filter_, page_size=page_size, job_view=job_view
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["list_jobs"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="jobs",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator

    def batch_delete_jobs(
        self,
        parent,
        filter_,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Deletes a list of ``Job``\ s by filter.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `filter_`:
            >>> filter_ = ''
            >>>
            >>> client.batch_delete_jobs(parent, filter_)

        Args:
            parent (str): Required. The resource name of the tenant under which the job is
                created.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenant/bar". If tenant id is unspecified, a
                default tenant is created. For example, "projects/foo".
            filter_ (str): Required. The filter string specifies the jobs to be deleted.

                Supported operator: =, AND

                The fields eligible for filtering are:

                -  ``companyName`` (Required)
                -  ``requisitionId`` (Required)

                Sample Query: companyName = "projects/foo/companies/bar" AND
                requisitionId = "req-1"
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "batch_delete_jobs" not in self._inner_api_calls:
            self._inner_api_calls[
                "batch_delete_jobs"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.batch_delete_jobs,
                default_retry=self._method_configs["BatchDeleteJobs"].retry,
                default_timeout=self._method_configs["BatchDeleteJobs"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.BatchDeleteJobsRequest(parent=parent, filter=filter_)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        self._inner_api_calls["batch_delete_jobs"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def search_jobs(
        self,
        parent,
        request_metadata,
        search_mode=None,
        job_query=None,
        enable_broadening=None,
        require_precise_result_size=None,
        histogram_queries=None,
        job_view=None,
        offset=None,
        page_size=None,
        order_by=None,
        diversification_level=None,
        custom_ranking_info=None,
        disable_keyword_match=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Searches for jobs using the provided ``SearchJobsRequest``.

        This call constrains the ``visibility`` of jobs present in the database,
        and only returns jobs that the caller has permission to search against.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `request_metadata`:
            >>> request_metadata = {}
            >>>
            >>> # Iterate over all results
            >>> for element in client.search_jobs(parent, request_metadata):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.search_jobs(parent, request_metadata).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): Required. The resource name of the tenant to search within.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenant/bar". If tenant id is unspecified, a
                default tenant is created. For example, "projects/foo".
            request_metadata (Union[dict, ~google.cloud.talent_v4beta1.types.RequestMetadata]): Required. The meta information collected about the job searcher, used to
                improve the search quality of the service. The identifiers (such as
                ``user_id``) are provided by users, and must be unique and consistent.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.RequestMetadata`
            search_mode (~google.cloud.talent_v4beta1.types.SearchMode): Mode of a search.

                Defaults to ``SearchMode.JOB_SEARCH``.
            job_query (Union[dict, ~google.cloud.talent_v4beta1.types.JobQuery]): Query used to search against jobs, such as keyword, location filters, etc.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.JobQuery`
            enable_broadening (bool): Controls whether to broaden the search when it produces sparse results.
                Broadened queries append results to the end of the matching results
                list.

                Defaults to false.
            require_precise_result_size (bool): Controls if the search job request requires the return of a precise
                count of the first 300 results. Setting this to ``true`` ensures
                consistency in the number of results per page. Best practice is to set
                this value to true if a client allows users to jump directly to a
                non-sequential search results page.

                Enabling this flag may adversely impact performance.

                Defaults to false.
            histogram_queries (list[Union[dict, ~google.cloud.talent_v4beta1.types.HistogramQuery]]): An expression specifies a histogram request against matching jobs.

                Expression syntax is an aggregation function call with histogram facets
                and other options.

                Available aggregation function calls are:

                -  ``count(string_histogram_facet)``: Count the number of matching
                   entities, for each distinct attribute value.
                -  ``count(numeric_histogram_facet, list of buckets)``: Count the number
                   of matching entities within each bucket.

                Data types:

                -  Histogram facet: facet names with format [a-zA-Z][a-zA-Z0-9\_]+.
                -  String: string like "any string with backslash escape for quote(")."
                -  Number: whole number and floating point number like 10, -1 and -0.01.
                -  List: list of elements with comma(,) separator surrounded by square
                   brackets, for example, [1, 2, 3] and ["one", "two", "three"].

                Built-in constants:

                -  MIN (minimum number similar to java Double.MIN\_VALUE)
                -  MAX (maximum number similar to java Double.MAX\_VALUE)

                Built-in functions:

                -  bucket(start, end[, label]): bucket built-in function creates a
                   bucket with range of \`start, end). Note that the end is exclusive,
                   for example, bucket(1, MAX, "positive number") or bucket(1, 10).

                Job histogram facets:

                -  company\_display\_name: histogram by [Job.company\_display\_name\`.
                -  employment\_type: histogram by ``Job.employment_types``, for example,
                   "FULL\_TIME", "PART\_TIME".
                -  company\_size: histogram by ``CompanySize``, for example, "SMALL",
                   "MEDIUM", "BIG".
                -  publish\_time\_in\_month: histogram by the
                   ``Job.posting_publish_time`` in months. Must specify list of numeric
                   buckets in spec.
                -  publish\_time\_in\_year: histogram by the
                   ``Job.posting_publish_time`` in years. Must specify list of numeric
                   buckets in spec.
                -  degree\_types: histogram by the ``Job.degree_types``, for example,
                   "Bachelors", "Masters".
                -  job\_level: histogram by the ``Job.job_level``, for example, "Entry
                   Level".
                -  country: histogram by the country code of jobs, for example, "US",
                   "FR".
                -  admin1: histogram by the admin1 code of jobs, which is a global
                   placeholder referring to the state, province, or the particular term
                   a country uses to define the geographic structure below the country
                   level, for example, "CA", "IL".
                -  city: histogram by a combination of the "city name, admin1 code". For
                   example, "Mountain View, CA", "New York, NY".
                -  admin1\_country: histogram by a combination of the "admin1 code,
                   country", for example, "CA, US", "IL, US".
                -  city\_coordinate: histogram by the city center's GPS coordinates
                   (latitude and longitude), for example, 37.4038522,-122.0987765. Since
                   the coordinates of a city center can change, customers may need to
                   refresh them periodically.
                -  locale: histogram by the ``Job.language_code``, for example, "en-US",
                   "fr-FR".
                -  language: histogram by the language subtag of the
                   ``Job.language_code``, for example, "en", "fr".
                -  category: histogram by the ``JobCategory``, for example,
                   "COMPUTER\_AND\_IT", "HEALTHCARE".
                -  base\_compensation\_unit: histogram by the
                   ``CompensationInfo.CompensationUnit`` of base salary, for example,
                   "WEEKLY", "MONTHLY".
                -  base\_compensation: histogram by the base salary. Must specify list
                   of numeric buckets to group results by.
                -  annualized\_base\_compensation: histogram by the base annualized
                   salary. Must specify list of numeric buckets to group results by.
                -  annualized\_total\_compensation: histogram by the total annualized
                   salary. Must specify list of numeric buckets to group results by.
                -  string\_custom\_attribute: histogram by string
                   ``Job.custom_attributes``. Values can be accessed via square bracket
                   notations like string\_custom\_attribute["key1"].
                -  numeric\_custom\_attribute: histogram by numeric
                   ``Job.custom_attributes``. Values can be accessed via square bracket
                   notations like numeric\_custom\_attribute["key1"]. Must specify list
                   of numeric buckets to group results by.

                Example expressions:

                -  ``count(admin1)``
                -  ``count(base_compensation, [bucket(1000, 10000), bucket(10000, 100000), bucket(100000, MAX)])``
                -  ``count(string_custom_attribute["some-string-custom-attribute"])``
                -  ``count(numeric_custom_attribute["some-numeric-custom-attribute"], [bucket(MIN, 0, "negative"), bucket(0, MAX, "non-negative"])``

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.HistogramQuery`
            job_view (~google.cloud.talent_v4beta1.types.JobView): The desired job attributes returned for jobs in the search response.
                Defaults to ``JobView.JOB_VIEW_SMALL`` if no value is specified.
            offset (int): An integer that specifies the current offset (that is, starting result
                location, amongst the jobs deemed by the API as relevant) in search
                results. This field is only considered if ``page_token`` is unset.

                The maximum allowed value is 5000. Otherwise an error is thrown.

                The maximum allowed value is 5000. Otherwise an error is thrown.

                For example, 0 means to return results starting from the first matching
                job, and 10 means to return from the 11th job. This can be used for
                pagination, (for example, pageSize = 10 and offset = 10 means to return
                from the second page).
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            order_by (str): The criteria determining how search results are sorted. Default is
                ``"relevance desc"``.

                Supported options are:

                -  ``"relevance desc"``: By relevance descending, as determined by the
                   API algorithms. Relevance thresholding of query results is only
                   available with this ordering.
                -  ``"posting_publish_time desc"``: By ``Job.posting_publish_time``
                   descending.
                -  ``"posting_update_time desc"``: By ``Job.posting_update_time``
                   descending.
                -  ``"title"``: By ``Job.title`` ascending.
                -  ``"title desc"``: By ``Job.title`` descending.
                -  ``"annualized_base_compensation"``: By job's
                   ``CompensationInfo.annualized_base_compensation_range`` ascending.
                   Jobs whose annualized base compensation is unspecified are put at the
                   end of search results.
                -  ``"annualized_base_compensation desc"``: By job's
                   ``CompensationInfo.annualized_base_compensation_range`` descending.
                   Jobs whose annualized base compensation is unspecified are put at the
                   end of search results.
                -  ``"annualized_total_compensation"``: By job's
                   ``CompensationInfo.annualized_total_compensation_range`` ascending.
                   Jobs whose annualized base compensation is unspecified are put at the
                   end of search results.
                -  ``"annualized_total_compensation desc"``: By job's
                   ``CompensationInfo.annualized_total_compensation_range`` descending.
                   Jobs whose annualized base compensation is unspecified are put at the
                   end of search results.
                -  ``"custom_ranking desc"``: By the relevance score adjusted to the
                   ``SearchJobsRequest.CustomRankingInfo.ranking_expression`` with
                   weight factor assigned by
                   ``SearchJobsRequest.CustomRankingInfo.importance_level`` in
                   descending order.
                -  Location sorting: Use the special syntax to order jobs by distance:
                   ``"distance_from('Hawaii')"``: Order by distance from Hawaii.
                   ``"distance_from(19.89, 155.5)"``: Order by distance from a
                   coordinate.
                   ``"distance_from('Hawaii'), distance_from('Puerto Rico')"``: Order by
                   multiple locations. See details below.
                   ``"distance_from('Hawaii'), distance_from(19.89, 155.5)"``: Order by
                   multiple locations. See details below. The string can have a maximum
                   of 256 characters. When multiple distance centers are provided, a job
                   that is close to any of the distance centers would have a high rank.
                   When a job has multiple locations, the job location closest to one of
                   the distance centers will be used. Jobs that don't have locations
                   will be ranked at the bottom. Distance is calculated with a precision
                   of 11.3 meters (37.4 feet). Diversification strategy is still applied
                   unless explicitly disabled in ``diversification_level``.
            diversification_level (~google.cloud.talent_v4beta1.types.DiversificationLevel): Controls whether highly similar jobs are returned next to each other in
                the search results. Jobs are identified as highly similar based on their
                titles, job categories, and locations. Highly similar results are
                clustered so that only one representative job of the cluster is
                displayed to the job seeker higher up in the results, with the other
                jobs being displayed lower down in the results.

                Defaults to ``DiversificationLevel.SIMPLE`` if no value is specified.
            custom_ranking_info (Union[dict, ~google.cloud.talent_v4beta1.types.CustomRankingInfo]): Controls over how job documents get ranked on top of existing relevance
                score (determined by API algorithm).

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.CustomRankingInfo`
            disable_keyword_match (bool): Controls whether to disable exact keyword match on ``Job.title``,
                ``Job.description``, ``Job.company_display_name``, ``Job.addresses``,
                ``Job.qualifications``. When disable keyword match is turned off, a
                keyword match returns jobs that do not match given category filters when
                there are matching keywords. For example, for the query "program
                manager," a result is returned even if the job posting has the title
                "software developer," which doesn't fall into "program manager"
                ontology, but does have "program manager" appearing in its description.

                For queries like "cloud" that don't contain title or location specific
                ontology, jobs with "cloud" keyword matches are returned regardless of
                this flag's value.

                Use ``Company.keyword_searchable_job_custom_attributes`` if
                company-specific globally matched custom field/attribute string values
                are needed. Enabling keyword match improves recall of subsequent search
                requests.

                Defaults to false.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~google.cloud.talent_v4beta1.types.MatchingJob` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "search_jobs" not in self._inner_api_calls:
            self._inner_api_calls[
                "search_jobs"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.search_jobs,
                default_retry=self._method_configs["SearchJobs"].retry,
                default_timeout=self._method_configs["SearchJobs"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.SearchJobsRequest(
            parent=parent,
            request_metadata=request_metadata,
            search_mode=search_mode,
            job_query=job_query,
            enable_broadening=enable_broadening,
            require_precise_result_size=require_precise_result_size,
            histogram_queries=histogram_queries,
            job_view=job_view,
            offset=offset,
            page_size=page_size,
            order_by=order_by,
            diversification_level=diversification_level,
            custom_ranking_info=custom_ranking_info,
            disable_keyword_match=disable_keyword_match,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["search_jobs"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="matching_jobs",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator

    def search_jobs_for_alert(
        self,
        parent,
        request_metadata,
        search_mode=None,
        job_query=None,
        enable_broadening=None,
        require_precise_result_size=None,
        histogram_queries=None,
        job_view=None,
        offset=None,
        page_size=None,
        order_by=None,
        diversification_level=None,
        custom_ranking_info=None,
        disable_keyword_match=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Searches for jobs using the provided ``SearchJobsRequest``.

        This API call is intended for the use case of targeting passive job
        seekers (for example, job seekers who have signed up to receive email
        alerts about potential job opportunities), and has different algorithmic
        adjustments that are targeted to passive job seekers.

        This call constrains the ``visibility`` of jobs present in the database,
        and only returns jobs the caller has permission to search against.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `request_metadata`:
            >>> request_metadata = {}
            >>>
            >>> # Iterate over all results
            >>> for element in client.search_jobs_for_alert(parent, request_metadata):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.search_jobs_for_alert(parent, request_metadata).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): Required. The resource name of the tenant to search within.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenant/bar". If tenant id is unspecified, a
                default tenant is created. For example, "projects/foo".
            request_metadata (Union[dict, ~google.cloud.talent_v4beta1.types.RequestMetadata]): Required. The meta information collected about the job searcher, used to
                improve the search quality of the service. The identifiers (such as
                ``user_id``) are provided by users, and must be unique and consistent.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.RequestMetadata`
            search_mode (~google.cloud.talent_v4beta1.types.SearchMode): Mode of a search.

                Defaults to ``SearchMode.JOB_SEARCH``.
            job_query (Union[dict, ~google.cloud.talent_v4beta1.types.JobQuery]): Query used to search against jobs, such as keyword, location filters, etc.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.JobQuery`
            enable_broadening (bool): Controls whether to broaden the search when it produces sparse results.
                Broadened queries append results to the end of the matching results
                list.

                Defaults to false.
            require_precise_result_size (bool): Controls if the search job request requires the return of a precise
                count of the first 300 results. Setting this to ``true`` ensures
                consistency in the number of results per page. Best practice is to set
                this value to true if a client allows users to jump directly to a
                non-sequential search results page.

                Enabling this flag may adversely impact performance.

                Defaults to false.
            histogram_queries (list[Union[dict, ~google.cloud.talent_v4beta1.types.HistogramQuery]]): An expression specifies a histogram request against matching jobs.

                Expression syntax is an aggregation function call with histogram facets
                and other options.

                Available aggregation function calls are:

                -  ``count(string_histogram_facet)``: Count the number of matching
                   entities, for each distinct attribute value.
                -  ``count(numeric_histogram_facet, list of buckets)``: Count the number
                   of matching entities within each bucket.

                Data types:

                -  Histogram facet: facet names with format [a-zA-Z][a-zA-Z0-9\_]+.
                -  String: string like "any string with backslash escape for quote(")."
                -  Number: whole number and floating point number like 10, -1 and -0.01.
                -  List: list of elements with comma(,) separator surrounded by square
                   brackets, for example, [1, 2, 3] and ["one", "two", "three"].

                Built-in constants:

                -  MIN (minimum number similar to java Double.MIN\_VALUE)
                -  MAX (maximum number similar to java Double.MAX\_VALUE)

                Built-in functions:

                -  bucket(start, end[, label]): bucket built-in function creates a
                   bucket with range of \`start, end). Note that the end is exclusive,
                   for example, bucket(1, MAX, "positive number") or bucket(1, 10).

                Job histogram facets:

                -  company\_display\_name: histogram by [Job.company\_display\_name\`.
                -  employment\_type: histogram by ``Job.employment_types``, for example,
                   "FULL\_TIME", "PART\_TIME".
                -  company\_size: histogram by ``CompanySize``, for example, "SMALL",
                   "MEDIUM", "BIG".
                -  publish\_time\_in\_month: histogram by the
                   ``Job.posting_publish_time`` in months. Must specify list of numeric
                   buckets in spec.
                -  publish\_time\_in\_year: histogram by the
                   ``Job.posting_publish_time`` in years. Must specify list of numeric
                   buckets in spec.
                -  degree\_types: histogram by the ``Job.degree_types``, for example,
                   "Bachelors", "Masters".
                -  job\_level: histogram by the ``Job.job_level``, for example, "Entry
                   Level".
                -  country: histogram by the country code of jobs, for example, "US",
                   "FR".
                -  admin1: histogram by the admin1 code of jobs, which is a global
                   placeholder referring to the state, province, or the particular term
                   a country uses to define the geographic structure below the country
                   level, for example, "CA", "IL".
                -  city: histogram by a combination of the "city name, admin1 code". For
                   example, "Mountain View, CA", "New York, NY".
                -  admin1\_country: histogram by a combination of the "admin1 code,
                   country", for example, "CA, US", "IL, US".
                -  city\_coordinate: histogram by the city center's GPS coordinates
                   (latitude and longitude), for example, 37.4038522,-122.0987765. Since
                   the coordinates of a city center can change, customers may need to
                   refresh them periodically.
                -  locale: histogram by the ``Job.language_code``, for example, "en-US",
                   "fr-FR".
                -  language: histogram by the language subtag of the
                   ``Job.language_code``, for example, "en", "fr".
                -  category: histogram by the ``JobCategory``, for example,
                   "COMPUTER\_AND\_IT", "HEALTHCARE".
                -  base\_compensation\_unit: histogram by the
                   ``CompensationInfo.CompensationUnit`` of base salary, for example,
                   "WEEKLY", "MONTHLY".
                -  base\_compensation: histogram by the base salary. Must specify list
                   of numeric buckets to group results by.
                -  annualized\_base\_compensation: histogram by the base annualized
                   salary. Must specify list of numeric buckets to group results by.
                -  annualized\_total\_compensation: histogram by the total annualized
                   salary. Must specify list of numeric buckets to group results by.
                -  string\_custom\_attribute: histogram by string
                   ``Job.custom_attributes``. Values can be accessed via square bracket
                   notations like string\_custom\_attribute["key1"].
                -  numeric\_custom\_attribute: histogram by numeric
                   ``Job.custom_attributes``. Values can be accessed via square bracket
                   notations like numeric\_custom\_attribute["key1"]. Must specify list
                   of numeric buckets to group results by.

                Example expressions:

                -  ``count(admin1)``
                -  ``count(base_compensation, [bucket(1000, 10000), bucket(10000, 100000), bucket(100000, MAX)])``
                -  ``count(string_custom_attribute["some-string-custom-attribute"])``
                -  ``count(numeric_custom_attribute["some-numeric-custom-attribute"], [bucket(MIN, 0, "negative"), bucket(0, MAX, "non-negative"])``

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.HistogramQuery`
            job_view (~google.cloud.talent_v4beta1.types.JobView): The desired job attributes returned for jobs in the search response.
                Defaults to ``JobView.JOB_VIEW_SMALL`` if no value is specified.
            offset (int): An integer that specifies the current offset (that is, starting result
                location, amongst the jobs deemed by the API as relevant) in search
                results. This field is only considered if ``page_token`` is unset.

                The maximum allowed value is 5000. Otherwise an error is thrown.

                The maximum allowed value is 5000. Otherwise an error is thrown.

                For example, 0 means to return results starting from the first matching
                job, and 10 means to return from the 11th job. This can be used for
                pagination, (for example, pageSize = 10 and offset = 10 means to return
                from the second page).
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            order_by (str): The criteria determining how search results are sorted. Default is
                ``"relevance desc"``.

                Supported options are:

                -  ``"relevance desc"``: By relevance descending, as determined by the
                   API algorithms. Relevance thresholding of query results is only
                   available with this ordering.
                -  ``"posting_publish_time desc"``: By ``Job.posting_publish_time``
                   descending.
                -  ``"posting_update_time desc"``: By ``Job.posting_update_time``
                   descending.
                -  ``"title"``: By ``Job.title`` ascending.
                -  ``"title desc"``: By ``Job.title`` descending.
                -  ``"annualized_base_compensation"``: By job's
                   ``CompensationInfo.annualized_base_compensation_range`` ascending.
                   Jobs whose annualized base compensation is unspecified are put at the
                   end of search results.
                -  ``"annualized_base_compensation desc"``: By job's
                   ``CompensationInfo.annualized_base_compensation_range`` descending.
                   Jobs whose annualized base compensation is unspecified are put at the
                   end of search results.
                -  ``"annualized_total_compensation"``: By job's
                   ``CompensationInfo.annualized_total_compensation_range`` ascending.
                   Jobs whose annualized base compensation is unspecified are put at the
                   end of search results.
                -  ``"annualized_total_compensation desc"``: By job's
                   ``CompensationInfo.annualized_total_compensation_range`` descending.
                   Jobs whose annualized base compensation is unspecified are put at the
                   end of search results.
                -  ``"custom_ranking desc"``: By the relevance score adjusted to the
                   ``SearchJobsRequest.CustomRankingInfo.ranking_expression`` with
                   weight factor assigned by
                   ``SearchJobsRequest.CustomRankingInfo.importance_level`` in
                   descending order.
                -  Location sorting: Use the special syntax to order jobs by distance:
                   ``"distance_from('Hawaii')"``: Order by distance from Hawaii.
                   ``"distance_from(19.89, 155.5)"``: Order by distance from a
                   coordinate.
                   ``"distance_from('Hawaii'), distance_from('Puerto Rico')"``: Order by
                   multiple locations. See details below.
                   ``"distance_from('Hawaii'), distance_from(19.89, 155.5)"``: Order by
                   multiple locations. See details below. The string can have a maximum
                   of 256 characters. When multiple distance centers are provided, a job
                   that is close to any of the distance centers would have a high rank.
                   When a job has multiple locations, the job location closest to one of
                   the distance centers will be used. Jobs that don't have locations
                   will be ranked at the bottom. Distance is calculated with a precision
                   of 11.3 meters (37.4 feet). Diversification strategy is still applied
                   unless explicitly disabled in ``diversification_level``.
            diversification_level (~google.cloud.talent_v4beta1.types.DiversificationLevel): Controls whether highly similar jobs are returned next to each other in
                the search results. Jobs are identified as highly similar based on their
                titles, job categories, and locations. Highly similar results are
                clustered so that only one representative job of the cluster is
                displayed to the job seeker higher up in the results, with the other
                jobs being displayed lower down in the results.

                Defaults to ``DiversificationLevel.SIMPLE`` if no value is specified.
            custom_ranking_info (Union[dict, ~google.cloud.talent_v4beta1.types.CustomRankingInfo]): Controls over how job documents get ranked on top of existing relevance
                score (determined by API algorithm).

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.CustomRankingInfo`
            disable_keyword_match (bool): Controls whether to disable exact keyword match on ``Job.title``,
                ``Job.description``, ``Job.company_display_name``, ``Job.addresses``,
                ``Job.qualifications``. When disable keyword match is turned off, a
                keyword match returns jobs that do not match given category filters when
                there are matching keywords. For example, for the query "program
                manager," a result is returned even if the job posting has the title
                "software developer," which doesn't fall into "program manager"
                ontology, but does have "program manager" appearing in its description.

                For queries like "cloud" that don't contain title or location specific
                ontology, jobs with "cloud" keyword matches are returned regardless of
                this flag's value.

                Use ``Company.keyword_searchable_job_custom_attributes`` if
                company-specific globally matched custom field/attribute string values
                are needed. Enabling keyword match improves recall of subsequent search
                requests.

                Defaults to false.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~google.cloud.talent_v4beta1.types.MatchingJob` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "search_jobs_for_alert" not in self._inner_api_calls:
            self._inner_api_calls[
                "search_jobs_for_alert"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.search_jobs_for_alert,
                default_retry=self._method_configs["SearchJobsForAlert"].retry,
                default_timeout=self._method_configs["SearchJobsForAlert"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.SearchJobsRequest(
            parent=parent,
            request_metadata=request_metadata,
            search_mode=search_mode,
            job_query=job_query,
            enable_broadening=enable_broadening,
            require_precise_result_size=require_precise_result_size,
            histogram_queries=histogram_queries,
            job_view=job_view,
            offset=offset,
            page_size=page_size,
            order_by=order_by,
            diversification_level=diversification_level,
            custom_ranking_info=custom_ranking_info,
            disable_keyword_match=disable_keyword_match,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["search_jobs_for_alert"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="matching_jobs",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator

    def batch_create_jobs(
        self,
        parent,
        jobs,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Begins executing a batch create jobs operation.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `jobs`:
            >>> jobs = []
            >>>
            >>> response = client.batch_create_jobs(parent, jobs)
            >>>
            >>> def callback(operation_future):
            ...     # Handle result.
            ...     result = operation_future.result()
            >>>
            >>> response.add_done_callback(callback)
            >>>
            >>> # Handle metadata.
            >>> metadata = response.metadata()

        Args:
            parent (str): Required. The resource name of the tenant under which the job is
                created.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenant/bar". If tenant id is unspecified, a
                default tenant is created. For example, "projects/foo".
            jobs (list[Union[dict, ~google.cloud.talent_v4beta1.types.Job]]): Required. The jobs to be created.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.Job`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.talent_v4beta1.types._OperationFuture` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "batch_create_jobs" not in self._inner_api_calls:
            self._inner_api_calls[
                "batch_create_jobs"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.batch_create_jobs,
                default_retry=self._method_configs["BatchCreateJobs"].retry,
                default_timeout=self._method_configs["BatchCreateJobs"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.BatchCreateJobsRequest(parent=parent, jobs=jobs)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        operation = self._inner_api_calls["batch_create_jobs"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )
        return google.api_core.operation.from_gapic(
            operation,
            self.transport._operations_client,
            job_service_pb2.JobOperationResult,
            metadata_type=common_pb2.BatchOperationMetadata,
        )

    def batch_update_jobs(
        self,
        parent,
        jobs,
        update_mask=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Begins executing a batch update jobs operation.

        Example:
            >>> from google.cloud import talent_v4beta1
            >>>
            >>> client = talent_v4beta1.JobServiceClient()
            >>>
            >>> parent = client.tenant_path('[PROJECT]', '[TENANT]')
            >>>
            >>> # TODO: Initialize `jobs`:
            >>> jobs = []
            >>>
            >>> response = client.batch_update_jobs(parent, jobs)
            >>>
            >>> def callback(operation_future):
            ...     # Handle result.
            ...     result = operation_future.result()
            >>>
            >>> response.add_done_callback(callback)
            >>>
            >>> # Handle metadata.
            >>> metadata = response.metadata()

        Args:
            parent (str): Required. The resource name of the tenant under which the job is
                created.

                The format is "projects/{project\_id}/tenants/{tenant\_id}". For
                example, "projects/foo/tenant/bar". If tenant id is unspecified, a
                default tenant is created. For example, "projects/foo".
            jobs (list[Union[dict, ~google.cloud.talent_v4beta1.types.Job]]): Required. The jobs to be updated.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.Job`
            update_mask (Union[dict, ~google.cloud.talent_v4beta1.types.FieldMask]): Strongly recommended for the best service experience. Be aware that it
                will also increase latency when checking the status of a batch
                operation.

                If ``update_mask`` is provided, only the specified fields in ``Job`` are
                updated. Otherwise all the fields are updated.

                A field mask to restrict the fields that are updated. Only top level
                fields of ``Job`` are supported.

                If ``update_mask`` is provided, The ``Job`` inside ``JobResult`` will
                only contains fields that is updated, plus the Id of the Job. Otherwise,
                ``Job`` will include all fields, which can yield a very large response.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.talent_v4beta1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.talent_v4beta1.types._OperationFuture` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "batch_update_jobs" not in self._inner_api_calls:
            self._inner_api_calls[
                "batch_update_jobs"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.batch_update_jobs,
                default_retry=self._method_configs["BatchUpdateJobs"].retry,
                default_timeout=self._method_configs["BatchUpdateJobs"].timeout,
                client_info=self._client_info,
            )

        request = job_service_pb2.BatchUpdateJobsRequest(
            parent=parent, jobs=jobs, update_mask=update_mask
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        operation = self._inner_api_calls["batch_update_jobs"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )
        return google.api_core.operation.from_gapic(
            operation,
            self.transport._operations_client,
            job_service_pb2.JobOperationResult,
            metadata_type=common_pb2.BatchOperationMetadata,
        )



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

from google.cloud import talent_v4beta1
from google.cloud.talent_v4beta1.proto import application_pb2
from google.cloud.talent_v4beta1.proto import application_service_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestApplicationServiceClient(object):
    def test_create_application(self):
        # Setup Expected Response
        name = "name3373707"
        external_id = "externalId-1153075697"
        profile = "profile-309425751"
        job = "job105405"
        company = "company950484093"
        outcome_notes = "outcomeNotes-355961964"
        job_title_snippet = "jobTitleSnippet-1100512972"
        expected_response = {
            "name": name,
            "external_id": external_id,
            "profile": profile,
            "job": job,
            "company": company,
            "outcome_notes": outcome_notes,
            "job_title_snippet": job_title_snippet,
        }
        expected_response = application_pb2.Application(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup Request
        parent = client.profile_path("[PROJECT]", "[TENANT]", "[PROFILE]")
        application = {}

        response = client.create_application(parent, application)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = application_service_pb2.CreateApplicationRequest(
            parent=parent, application=application
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_application_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup request
        parent = client.profile_path("[PROJECT]", "[TENANT]", "[PROFILE]")
        application = {}

        with pytest.raises(CustomException):
            client.create_application(parent, application)

    def test_get_application(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        external_id = "externalId-1153075697"
        profile = "profile-309425751"
        job = "job105405"
        company = "company950484093"
        outcome_notes = "outcomeNotes-355961964"
        job_title_snippet = "jobTitleSnippet-1100512972"
        expected_response = {
            "name": name_2,
            "external_id": external_id,
            "profile": profile,
            "job": job,
            "company": company,
            "outcome_notes": outcome_notes,
            "job_title_snippet": job_title_snippet,
        }
        expected_response = application_pb2.Application(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup Request
        name = client.application_path(
            "[PROJECT]", "[TENANT]", "[PROFILE]", "[APPLICATION]"
        )

        response = client.get_application(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = application_service_pb2.GetApplicationRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_application_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup request
        name = client.application_path(
            "[PROJECT]", "[TENANT]", "[PROFILE]", "[APPLICATION]"
        )

        with pytest.raises(CustomException):
            client.get_application(name)

    def test_update_application(self):
        # Setup Expected Response
        name = "name3373707"
        external_id = "externalId-1153075697"
        profile = "profile-309425751"
        job = "job105405"
        company = "company950484093"
        outcome_notes = "outcomeNotes-355961964"
        job_title_snippet = "jobTitleSnippet-1100512972"
        expected_response = {
            "name": name,
            "external_id": external_id,
            "profile": profile,
            "job": job,
            "company": company,
            "outcome_notes": outcome_notes,
            "job_title_snippet": job_title_snippet,
        }
        expected_response = application_pb2.Application(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup Request
        application = {}

        response = client.update_application(application)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = application_service_pb2.UpdateApplicationRequest(
            application=application
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_application_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup request
        application = {}

        with pytest.raises(CustomException):
            client.update_application(application)

    def test_delete_application(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup Request
        name = client.application_path(
            "[PROJECT]", "[TENANT]", "[PROFILE]", "[APPLICATION]"
        )

        client.delete_application(name)

        assert len(channel.requests) == 1
        expected_request = application_service_pb2.DeleteApplicationRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_application_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup request
        name = client.application_path(
            "[PROJECT]", "[TENANT]", "[PROFILE]", "[APPLICATION]"
        )

        with pytest.raises(CustomException):
            client.delete_application(name)

    def test_list_applications(self):
        # Setup Expected Response
        next_page_token = ""
        applications_element = {}
        applications = [applications_element]
        expected_response = {
            "next_page_token": next_page_token,
            "applications": applications,
        }
        expected_response = application_service_pb2.ListApplicationsResponse(
            **expected_response
        )

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup Request
        parent = client.profile_path("[PROJECT]", "[TENANT]", "[PROFILE]")

        paged_list_response = client.list_applications(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.applications[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = application_service_pb2.ListApplicationsRequest(
            parent=parent
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_applications_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.ApplicationServiceClient()

        # Setup request
        parent = client.profile_path("[PROJECT]", "[TENANT]", "[PROFILE]")

        paged_list_response = client.list_applications(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/histogram.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/histogram.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\016HistogramProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n1google/cloud/talent_v4beta1/proto/histogram.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.proto")\n\x0eHistogramQuery\x12\x17\n\x0fhistogram_query\x18\x01 \x01(\t"\xb6\x01\n\x14HistogramQueryResult\x12\x17\n\x0fhistogram_query\x18\x01 \x01(\t\x12S\n\thistogram\x18\x02 \x03(\x0b\x32@.google.cloud.talent.v4beta1.HistogramQueryResult.HistogramEntry\x1a\x30\n\x0eHistogramEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x42|\n\x1f\x63om.google.cloud.talent.v4beta1B\x0eHistogramProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_HISTOGRAMQUERY = _descriptor.Descriptor(
    name="HistogramQuery",
    full_name="google.cloud.talent.v4beta1.HistogramQuery",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="histogram_query",
            full_name="google.cloud.talent.v4beta1.HistogramQuery.histogram_query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=112,
    serialized_end=153,
)


_HISTOGRAMQUERYRESULT_HISTOGRAMENTRY = _descriptor.Descriptor(
    name="HistogramEntry",
    full_name="google.cloud.talent.v4beta1.HistogramQueryResult.HistogramEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.talent.v4beta1.HistogramQueryResult.HistogramEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.talent.v4beta1.HistogramQueryResult.HistogramEntry.value",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=290,
    serialized_end=338,
)

_HISTOGRAMQUERYRESULT = _descriptor.Descriptor(
    name="HistogramQueryResult",
    full_name="google.cloud.talent.v4beta1.HistogramQueryResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="histogram_query",
            full_name="google.cloud.talent.v4beta1.HistogramQueryResult.histogram_query",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="histogram",
            full_name="google.cloud.talent.v4beta1.HistogramQueryResult.histogram",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_HISTOGRAMQUERYRESULT_HISTOGRAMENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=156,
    serialized_end=338,
)

_HISTOGRAMQUERYRESULT_HISTOGRAMENTRY.containing_type = _HISTOGRAMQUERYRESULT
_HISTOGRAMQUERYRESULT.fields_by_name[
    "histogram"
].message_type = _HISTOGRAMQUERYRESULT_HISTOGRAMENTRY
DESCRIPTOR.message_types_by_name["HistogramQuery"] = _HISTOGRAMQUERY
DESCRIPTOR.message_types_by_name["HistogramQueryResult"] = _HISTOGRAMQUERYRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HistogramQuery = _reflection.GeneratedProtocolMessageType(
    "HistogramQuery",
    (_message.Message,),
    dict(
        DESCRIPTOR=_HISTOGRAMQUERY,
        __module__="google.cloud.talent_v4beta1.proto.histogram_pb2",
        __doc__="""The histogram request.
  
  
  Attributes:
      histogram_query:
          An expression specifies a histogram request against matching
          resources (for example, jobs, profiles) for searches.  See [Se
          archJobsRequest.histogram\_queries][google.cloud.talent.v4beta
          1.SearchJobsRequest.histogram\_queries] and [SearchProfilesReq
          uest.histogram\_queries][google.cloud.talent.v4beta1.SearchPro
          filesRequest.histogram\_queries] for details about syntax.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.HistogramQuery)
    ),
)
_sym_db.RegisterMessage(HistogramQuery)

HistogramQueryResult = _reflection.GeneratedProtocolMessageType(
    "HistogramQueryResult",
    (_message.Message,),
    dict(
        HistogramEntry=_reflection.GeneratedProtocolMessageType(
            "HistogramEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_HISTOGRAMQUERYRESULT_HISTOGRAMENTRY,
                __module__="google.cloud.talent_v4beta1.proto.histogram_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.HistogramQueryResult.HistogramEntry)
            ),
        ),
        DESCRIPTOR=_HISTOGRAMQUERYRESULT,
        __module__="google.cloud.talent_v4beta1.proto.histogram_pb2",
        __doc__="""Histogram result that matches
  [HistogramQuery][google.cloud.talent.v4beta1.HistogramQuery] specified
  in searches.
  
  
  Attributes:
      histogram_query:
          Requested histogram expression.
      histogram:
          A map from the values of the facet associated with distinct
          values to the number of matching entries with corresponding
          value.  The key format is:  -  (for string histogram) string
          values stored in the field. -  (for named numeric bucket) name
          specified in ``bucket()`` function,    like for ``bucket(0,
          MAX, "non-negative")``, the key will be    ``non-negative``. -
          (for anonymous numeric bucket) range formatted as
          ``<low>-<high>``,    for example, ``0-1000``, ``MIN-0``, and
          ``0-MAX``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.HistogramQueryResult)
    ),
)
_sym_db.RegisterMessage(HistogramQueryResult)
_sym_db.RegisterMessage(HistogramQueryResult.HistogramEntry)


DESCRIPTOR._options = None
_HISTOGRAMQUERYRESULT_HISTOGRAMENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.talent_v4beta1.proto import (
    company_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    company_service_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CompanyServiceStub(object):
    """A service that handles company management, including CRUD and enumeration.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateCompany = channel.unary_unary(
            "/google.cloud.talent.v4beta1.CompanyService/CreateCompany",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.CreateCompanyRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2.Company.FromString,
        )
        self.GetCompany = channel.unary_unary(
            "/google.cloud.talent.v4beta1.CompanyService/GetCompany",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.GetCompanyRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2.Company.FromString,
        )
        self.UpdateCompany = channel.unary_unary(
            "/google.cloud.talent.v4beta1.CompanyService/UpdateCompany",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.UpdateCompanyRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2.Company.FromString,
        )
        self.DeleteCompany = channel.unary_unary(
            "/google.cloud.talent.v4beta1.CompanyService/DeleteCompany",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.DeleteCompanyRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ListCompanies = channel.unary_unary(
            "/google.cloud.talent.v4beta1.CompanyService/ListCompanies",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.ListCompaniesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.ListCompaniesResponse.FromString,
        )


class CompanyServiceServicer(object):
    """A service that handles company management, including CRUD and enumeration.
  """

    def CreateCompany(self, request, context):
        """Creates a new company entity.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCompany(self, request, context):
        """Retrieves specified company.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateCompany(self, request, context):
        """Updates specified company.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteCompany(self, request, context):
        """Deletes specified company.
    Prerequisite: The company has no jobs associated with it.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListCompanies(self, request, context):
        """Lists all companies associated with the project.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CompanyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateCompany": grpc.unary_unary_rpc_method_handler(
            servicer.CreateCompany,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.CreateCompanyRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2.Company.SerializeToString,
        ),
        "GetCompany": grpc.unary_unary_rpc_method_handler(
            servicer.GetCompany,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.GetCompanyRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2.Company.SerializeToString,
        ),
        "UpdateCompany": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateCompany,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.UpdateCompanyRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__pb2.Company.SerializeToString,
        ),
        "DeleteCompany": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteCompany,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.DeleteCompanyRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ListCompanies": grpc.unary_unary_rpc_method_handler(
            servicer.ListCompanies,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.ListCompaniesRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_company__service__pb2.ListCompaniesResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.talent.v4beta1.CompanyService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.talent_v4beta1.proto import (
    tenant_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    tenant_service_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class TenantServiceStub(object):
    """A service that handles tenant management, including CRUD and enumeration.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateTenant = channel.unary_unary(
            "/google.cloud.talent.v4beta1.TenantService/CreateTenant",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.CreateTenantRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2.Tenant.FromString,
        )
        self.GetTenant = channel.unary_unary(
            "/google.cloud.talent.v4beta1.TenantService/GetTenant",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.GetTenantRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2.Tenant.FromString,
        )
        self.UpdateTenant = channel.unary_unary(
            "/google.cloud.talent.v4beta1.TenantService/UpdateTenant",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.UpdateTenantRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2.Tenant.FromString,
        )
        self.DeleteTenant = channel.unary_unary(
            "/google.cloud.talent.v4beta1.TenantService/DeleteTenant",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.DeleteTenantRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ListTenants = channel.unary_unary(
            "/google.cloud.talent.v4beta1.TenantService/ListTenants",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.ListTenantsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.ListTenantsResponse.FromString,
        )


class TenantServiceServicer(object):
    """A service that handles tenant management, including CRUD and enumeration.
  """

    def CreateTenant(self, request, context):
        """Creates a new tenant entity.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTenant(self, request, context):
        """Retrieves specified tenant.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTenant(self, request, context):
        """Updates specified tenant.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTenant(self, request, context):
        """Deletes specified tenant.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListTenants(self, request, context):
        """Lists all tenants associated with the project.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_TenantServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateTenant": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTenant,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.CreateTenantRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2.Tenant.SerializeToString,
        ),
        "GetTenant": grpc.unary_unary_rpc_method_handler(
            servicer.GetTenant,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.GetTenantRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2.Tenant.SerializeToString,
        ),
        "UpdateTenant": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTenant,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.UpdateTenantRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2.Tenant.SerializeToString,
        ),
        "DeleteTenant": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTenant,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.DeleteTenantRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ListTenants": grpc.unary_unary_rpc_method_handler(
            servicer.ListTenants,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.ListTenantsRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__service__pb2.ListTenantsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.talent.v4beta1.TenantService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.talent_v4beta1.proto import (
    profile_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    profile_service_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class ProfileServiceStub(object):
    """A service that handles profile management, including profile CRUD,
  enumeration and search.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.ListProfiles = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ProfileService/ListProfiles",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.ListProfilesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.ListProfilesResponse.FromString,
        )
        self.CreateProfile = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ProfileService/CreateProfile",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.CreateProfileRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2.Profile.FromString,
        )
        self.GetProfile = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ProfileService/GetProfile",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.GetProfileRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2.Profile.FromString,
        )
        self.UpdateProfile = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ProfileService/UpdateProfile",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.UpdateProfileRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2.Profile.FromString,
        )
        self.DeleteProfile = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ProfileService/DeleteProfile",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.DeleteProfileRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.SearchProfiles = channel.unary_unary(
            "/google.cloud.talent.v4beta1.ProfileService/SearchProfiles",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.SearchProfilesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.SearchProfilesResponse.FromString,
        )


class ProfileServiceServicer(object):
    """A service that handles profile management, including profile CRUD,
  enumeration and search.
  """

    def ListProfiles(self, request, context):
        """Lists profiles by filter. The order is unspecified.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateProfile(self, request, context):
        """Creates and returns a new profile.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetProfile(self, request, context):
        """Gets the specified profile.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateProfile(self, request, context):
        """Updates the specified profile and returns the updated result.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteProfile(self, request, context):
        """Deletes the specified profile.
    Prerequisite: The profile has no associated applications or assignments
    associated.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchProfiles(self, request, context):
        """Searches for profiles within a tenant.

    For example, search by raw queries "software engineer in Mountain View" or
    search by structured filters (location filter, education filter, etc.).

    See [SearchProfilesRequest][google.cloud.talent.v4beta1.SearchProfilesRequest] for more information.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ProfileServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ListProfiles": grpc.unary_unary_rpc_method_handler(
            servicer.ListProfiles,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.ListProfilesRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.ListProfilesResponse.SerializeToString,
        ),
        "CreateProfile": grpc.unary_unary_rpc_method_handler(
            servicer.CreateProfile,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.CreateProfileRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2.Profile.SerializeToString,
        ),
        "GetProfile": grpc.unary_unary_rpc_method_handler(
            servicer.GetProfile,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.GetProfileRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2.Profile.SerializeToString,
        ),
        "UpdateProfile": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateProfile,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.UpdateProfileRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2.Profile.SerializeToString,
        ),
        "DeleteProfile": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteProfile,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.DeleteProfileRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "SearchProfiles": grpc.unary_unary_rpc_method_handler(
            servicer.SearchProfiles,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.SearchProfilesRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__service__pb2.SearchProfilesResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.talent.v4beta1.ProfileService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
